MultiTestRunner: Always use absolute path names for tests.

Also, fix a function name I forgot to update.


git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@77064 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/utils/test/TestRunner.py b/utils/test/TestRunner.py
index 5639a37..84964c8 100755
--- a/utils/test/TestRunner.py
+++ b/utils/test/TestRunner.py
@@ -308,7 +308,7 @@
     return clangcc
     
 def getTestOutputBase(dir, testpath):
     """getTestOutputPath(dir, testpath) - Get the full path for temporary files
     corresponding to the given test path."""
 
     # Form the output base out of the test parent directory name and the test
@@ -345,7 +345,7 @@
 
     for path in args:
         command = path
-        output = getTestOutputPath('Output', path) + '.out'
+        output = getTestOutputBase('Output', path) + '.out'
         testname = path
         
         res = runOneTest(path, command, output, testname,
@@ -308,7 +308,7 @@
     
 def getTestOutputBase(dir, testpath):
-    """getTestOutputPath(dir, testpath) - Get the full path for temporary files
+    """getTestOutputBase(dir, testpath) - Get the full path for temporary files
     corresponding to the given test path."""
 